3 ms·
For a DataFrame with 1 column containing integers 0 to 99,999, in Python I'm seeing ~16ms to add up the column by iterating with itertuples (index false, name n
by Tarrosion 6y ago
For a DataFrame with 1 column containing integers 0 to 99,999, in Python I'm seeing ~16ms to add up the column by iterating with itertuples (index false, name none - which I didn't know helped performance, so thanks!). Julia it's 8ms to add up when iterating with eachrow and accessing the column by name.
So ~2x faster in Julia? Though it's a sort of awkward comparison, since this type of iteration seems a little anti-idiomatic in Python/pandas and doesn't fully leverage type information in Julia.